<div align="center"><b>&#1576;&#1587;&#1605; &#1575;&#1604;&#1604;&#1607; &#1575;&#1604;&#1585;&#1581;&#1605;&#1606; &#1575;&#1604;&#1585;&#1581;&#1610;&#1605;</b></div>
<div align="center">In the name of Allah, the Compassionate, the Merciful</div>

# GreyOpt

[![Apache 2.0 License](https://img.shields.io/badge/license-Apache--2.0-blue.svg)](https://github.com/greyopt/greyopt/blob/master/LICENSE.txt)

GreyOpt is a software package for large-scale grey-box optimization.

* **Website (and documentation):** <https://greyopt.github.io>
* **Source:** <https://github.com/greyopt/greyopt>
* **Bug reports:** <https://github.com/greyopt/greyopt/issues>
